Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(319)

Unified Diff: components/nacl/renderer/plugin/pnacl_translate_thread.h

Issue 1005173006: Add a switch for using PNaCl Subzero and use it for -O0 translation. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix takefileinfo Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/nacl/renderer/plugin/pnacl_translate_thread.h
diff --git a/components/nacl/renderer/plugin/pnacl_translate_thread.h b/components/nacl/renderer/plugin/pnacl_translate_thread.h
index d9c58899e1834559d5ed4dd311fd5178eaca6dd6..3c6b622a0ce25376cd1e4c267e5aa288d9ca5338 100644
--- a/components/nacl/renderer/plugin/pnacl_translate_thread.h
+++ b/components/nacl/renderer/plugin/pnacl_translate_thread.h
@@ -40,12 +40,13 @@ class PnaclTranslateThread {
// as it is passed in with PutBytes.
void RunTranslate(const pp::CompletionCallback& finish_callback,
const std::vector<TempFile*>* obj_files,
+ int num_threads,
TempFile* nexe_file,
nacl::DescWrapper* invalid_desc_wrapper,
ErrorInfo* error_info,
PnaclResources* resources,
PP_PNaClOptions* pnacl_options,
- const std::string &architecture_attributes,
+ const std::string& architecture_attributes,
PnaclCoordinator* coordinator,
Plugin* plugin);
@@ -88,12 +89,12 @@ class PnaclTranslateThread {
nacl::scoped_ptr<NaClThread> translate_thread_;
// Used to guard llc_subprocess and ld_subprocess
struct NaClMutex subprocess_mu_;
- nacl::scoped_ptr<NaClSubprocess> llc_subprocess_;
+ nacl::scoped_ptr<NaClSubprocess> compiler_subprocess_;
nacl::scoped_ptr<NaClSubprocess> ld_subprocess_;
// Used to ensure the subprocesses don't get shutdown more than once.
- bool llc_subprocess_active_;
+ bool compiler_subprocess_active_;
bool ld_subprocess_active_;
bool subprocesses_aborted_;
@@ -116,6 +117,7 @@ class PnaclTranslateThread {
// Data about the translation files, owned by the coordinator
const std::vector<TempFile*>* obj_files_;
+ int num_threads_;
TempFile* nexe_file_;
nacl::DescWrapper* invalid_desc_wrapper_;
ErrorInfo* coordinator_error_info_;
@@ -88,12 +89,12 @@ class PnaclTranslateThread {
nacl::scoped_ptr<NaClThread> translate_thread_;
- // Used to guard llc_subprocess and ld_subprocess
+ // Used to guard compiler_subprocess and ld_subprocess
struct NaClMutex subprocess_mu_;
« no previous file with comments | « components/nacl/renderer/plugin/pnacl_resources.cc ('k') | components/nacl/renderer/plugin/pnacl_translate_thread.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698